bday: Custom gift generator for birthdays

Description Usage Arguments Details Author(s) Examples

Description

This function will automatically generate gifts and presents for birthday boys or girls.

Usage

1

Arguments

name

Your name or whatever character string you want. I don't care.

Details

All you have to do is add your name to this function as it is the only parameter.

Author(s)

Brandon Monier, brandon.monier@sdstate.edu

Examples

1
2
3
  
    bday(name = "Ronald Reagan")
  

btmonier/bday documentation built on May 12, 2019, 4:25 p.m.