Description Usage Arguments Details Author(s) Examples
This function will automatically generate gifts and presents for birthday boys or girls.
1 |
name |
Your name or whatever character string you want. I don't care. |
All you have to do is add your name to this function as it is the only parameter.
Brandon Monier, brandon.monier@sdstate.edu
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.